# MaD GUI
**M**achine Learning 
**a**nd 
**D**ata Analytics 
**G**raphical 
**U**ser 
**I**nterface

[![Documentation Status](https://readthedocs.org/projects/mad-gui/badge/?version=latest)](https://mad-gui.readthedocs.io/en/latest/?badge=latest)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

## What is it?
The MaD GUI is a framework for processing time series data. Its use-cases include visualization, annotation (manual or automated), and algorithmic processing of visualized data and annotations. More information:

 - [Documentation](https://mad-gui.readthedocs.io/en/latest/README.html) 
 - [Github Repository](https://github.com/mad-lab-fau/mad-gui)
 - [YouTube Playlist](https://www.youtube.com/watch?v=akxcuFOesC8&list=PLf4GpKhBjGcswKIkNeahNt5nDxt8oXPue)
